@@ -1,3 +1,5 @@
+#![forbid(unsafe_code)]
+
 mod default_environment;
 mod interpreter;
 mod parser;
@@ -12,26 +14,26 @@ pub mod utils;
 pub mod macros;
 
 use model::Env;
-use std::io::Write;
-use std::{cell::RefCell, io, rc::Rc};
+use std::io::{self, prelude::*};
+use std::{cell::RefCell, rc::Rc};
 
 // 🦀 I am all over this project!
 /// Starts a REPL prompt at stdin/stdout. **This will block the current thread.**
 pub fn start_repl(env: Option<Env>) {
     let env_rc = Rc::new(RefCell::new(env.unwrap_or_else(default_env)));
 
-    loop {
-        print!("> ");
-        io::stdout().flush().unwrap();
-
-        let mut buf = String::new();
-        io::stdin().read_line(&mut buf).unwrap();
-
-        let res = eval_block(env_rc.clone(), parse(&buf).filter_map(|a| a.ok()));
-
-        match res {
+    print!("> ");
+    io::stdout().flush().unwrap();
+    for line in io::stdin().lock().lines() {
+        match eval_block(env_rc.clone(), parse(&line.unwrap()).filter_map(|a| a.ok())) {
             Ok(val) => println!("{}", val),
             Err(e) => println!("{}", e),
         };
+
+        print!("> ");
+        io::stdout().flush().unwrap();
     }
+
+    // Properly go to the next line after quitting
+    println!();
 }
